(this.webpackJsonpstreamlit_nivo_component=this.webpackJsonpstreamlit_nivo_component||[]).push([[0],{182:function(e,t,a){e.exports=a(306)},306:function(e,t,a){"use strict";a.r(t);var n=a(2),c=a.n(n),r=a(89),s=a.n(r),i=a(124),l=a(173),o=a(175),m=a(172),p=a(174),u=Object(i.b)((function(e){var t=e.args,a=t.data,r=t.layout,s=t.key,u={};return u.height=r.height||"360px",Object(n.useEffect)((function(){i.a.setFrameHeight()})),c.a.createElement("div",{style:u,key:s},r.title&&c.a.createElement("h3",null,r.title),"bump"===r.type&&c.a.createElement(l.a,Object.assign({data:a},r)),"calendar"===r.type&&c.a.createElement(o.a,Object.assign({data:a},r)),"chord"===r.type&&c.a.createElement(m.a,Object.assign({data:a},r)),"sankey"===r.type&&c.a.createElement(p.a,Object.assign({data:a},r)))}));s.a.render(c.a.createElement(u,null),document.getElementById("root"))}},[[182,1,2]]]);
//# sourceMappingURL=main.27f25157.chunk.js.map