self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "5d603ba53fbaff76a2ed995f1777fe26",
    "url": "./index.html"
  },
  {
    "revision": "f25a0b914210af562d98",
    "url": "./static/js/2.52f8f681.chunk.js"
  },
  {
    "revision": "465ff09073ee359151abc124f9b2a2ea",
    "url": "./static/js/2.52f8f681.chunk.js.LICENSE.txt"
  },
  {
    "revision": "9916620986b9faa89e1a",
    "url": "./static/js/main.27f25157.chunk.js"
  },
  {
    "revision": "b0c4049cef2f79202da3",
    "url": "./static/js/runtime-main.7e2c8680.js"
  }
]);