import setuptools

setuptools.setup(
    name="streamlit-nivo",
    version="0.1.8",
    author="Ahmed Saleh",
    author_email="a.saleh.ismael@gmail.com",
    description="Render Nivo charts in Streamlit",
    long_description="Render Nivo charts in Streamlit",
    long_description_content_type="text/plain",
    url="https://github.com/aswan-heart-centre/streamlit_nivo",
    packages=setuptools.find_packages(),
    include_package_data=True,
    classifiers=[],
    python_requires=">=3.6",
    install_requires=[
        "streamlit >= 0.63",
    ],
)
